# WWW::SwaggerClient::ReviewsApi

## Load the API package
```perl
use WWW::SwaggerClient::Object::ReviewsApi;
```

All URIs are relative to *https://reputationcrm.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_reviews_by_company_id**](ReviewsApi.md#get_reviews_by_company_id) | **GET** /getReviewsByCompanyID | Get X last reviews less than X days old of a company
[**get_reviews_by_company_id_and_rating**](ReviewsApi.md#get_reviews_by_company_id_and_rating) | **GET** /getReviewsByCompanyIdAndRating | Get X last reviews that equal or over X stars of a company
[**get_reviews_by_company_id_and_review_site**](ReviewsApi.md#get_reviews_by_company_id_and_review_site) | **GET** /getReviewsByCompanyIDAndReviewSite | Get X last reviews less than X days old of a review site of a company
[**get_reviews_by_company_id_rating_and_review_site**](ReviewsApi.md#get_reviews_by_company_id_rating_and_review_site) | **GET** /getReviewsByCompanyIDRatingAndReviewSite | Get X last reviews that equal or over X stars of a review site of a company
[**get_reviews_by_user_name**](ReviewsApi.md#get_reviews_by_user_name) | **GET** /getReviewsByUserName | Get X last reviews less than X days old of an account
[**get_reviews_by_user_name_and_rating**](ReviewsApi.md#get_reviews_by_user_name_and_rating) | **GET** /getReviewsByUserNameAndRating | Get X last reviews that equal or over X stars of an account
[**get_reviews_by_user_name_and_review_site**](ReviewsApi.md#get_reviews_by_user_name_and_review_site) | **GET** /getReviewsByUserNameAndReviewSite | Get X last reviews less than X days old of a review site of an account
[**get_reviews_by_user_name_rating_and_review_site**](ReviewsApi.md#get_reviews_by_user_name_rating_and_review_site) | **GET** /getReviewsByUserNameRatingAndReviewSite | Get X last reviews that equal or over X stars of a review site of an account
[**post_comment_on_review**](ReviewsApi.md#post_comment_on_review) | **POST** /postCommentOnReview | Comment on a Feedback / Review


# **get_reviews_by_company_id**
> ARRAY[Review] get_reviews_by_company_id(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days)

Get X last reviews less than X days old of a company

Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $companyid = 'companyid_example'; # string | Company ID
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back

eval { 
    my $result = $api_instance->get_reviews_by_company_id(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_company_id: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_company_id_and_rating**
> ARRAY[Review] get_reviews_by_company_id_and_rating(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, minimum_ratings => $minimum_ratings, maximum_ratings => $maximum_ratings)

Get X last reviews that equal or over X stars of a company

Get X last reviews that between X stars (For example, last 50 reviews between 2 to 5 stars)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $companyid = 'companyid_example'; # string | Company ID
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back
my $minimum_ratings = 'minimum_ratings_example'; # string | Minimum review rating (reviews that are equal or over minimumRatings stars)
my $maximum_ratings = 'maximum_ratings_example'; # string | Maximum review rating

eval { 
    my $result = $api_instance->get_reviews_by_company_id_and_rating(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, minimum_ratings => $minimum_ratings, maximum_ratings => $maximum_ratings);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_company_id_and_rating: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 
 **minimum_ratings** | **string**| Minimum review rating (reviews that are equal or over minimumRatings stars) | 
 **maximum_ratings** | **string**| Maximum review rating | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_company_id_and_review_site**
> ARRAY[Review] get_reviews_by_company_id_and_review_site(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, reviews_site => $reviews_site)

Get X last reviews less than X days old of a review site of a company

Get X last reviews less than X days old of a review site (For example, Google reviews…)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $companyid = 'companyid_example'; # string | Company ID
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back
my $reviews_site = 'reviews_site_example'; # string | Review site name

eval { 
    my $result = $api_instance->get_reviews_by_company_id_and_review_site(companyid => $companyid, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, reviews_site => $reviews_site);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_company_id_and_review_site: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 
 **reviews_site** | **string**| Review site name | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_company_id_rating_and_review_site**
> ARRAY[Review] get_reviews_by_company_id_rating_and_review_site(companyid => $companyid, how_many_reviews => $how_many_reviews, minimum_ratings => $minimum_ratings, reviews_site => $reviews_site)

Get X last reviews that equal or over X stars of a review site of a company

Get X last reviews that equal or over X stars of a review site (For example, Google reviews…)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $companyid = 'companyid_example'; # string | Company ID
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $minimum_ratings = 'minimum_ratings_example'; # string | Minimum review rating (reviews that are equal or over minimumRatings stars)
my $reviews_site = 'reviews_site_example'; # string | Review site name

eval { 
    my $result = $api_instance->get_reviews_by_company_id_rating_and_review_site(companyid => $companyid, how_many_reviews => $how_many_reviews, minimum_ratings => $minimum_ratings, reviews_site => $reviews_site);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_company_id_rating_and_review_site: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **companyid** | **string**| Company ID | 
 **how_many_reviews** | **string**| How many reviews | 
 **minimum_ratings** | **string**| Minimum review rating (reviews that are equal or over minimumRatings stars) | 
 **reviews_site** | **string**| Review site name | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_user_name**
> ARRAY[Review] get_reviews_by_user_name(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days)

Get X last reviews less than X days old of an account

Get X last reviews less than X days old (For example, last 100 reviews that are less than 365 days old)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $username = 'username_example'; # string | User Name or Email address
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back

eval { 
    my $result = $api_instance->get_reviews_by_user_name(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_user_name: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **string**| User Name or Email address | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_user_name_and_rating**
> ARRAY[Review] get_reviews_by_user_name_and_rating(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, minimum_ratings => $minimum_ratings)

Get X last reviews that equal or over X stars of an account

Get X last reviews that equal or over X stars (For example, last 50 reviews that are equal or over 4 stars)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $username = 'username_example'; # string | User Name or Email address
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back
my $minimum_ratings = 'minimum_ratings_example'; # string | Minimum review rating (reviews that are equal or over minimumRatings stars)

eval { 
    my $result = $api_instance->get_reviews_by_user_name_and_rating(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, minimum_ratings => $minimum_ratings);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_user_name_and_rating: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **string**| User Name or Email address | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 
 **minimum_ratings** | **string**| Minimum review rating (reviews that are equal or over minimumRatings stars) | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_user_name_and_review_site**
> ARRAY[Review] get_reviews_by_user_name_and_review_site(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, reviews_site => $reviews_site)

Get X last reviews less than X days old of a review site of an account

Get X last reviews less than X days old of a review site (For Example, Google reviews…)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $username = 'username_example'; # string | User Name or Email address
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $last_how_many_days = 'last_how_many_days_example'; # string | How many days back
my $reviews_site = 'reviews_site_example'; # string | Review site name

eval { 
    my $result = $api_instance->get_reviews_by_user_name_and_review_site(username => $username, how_many_reviews => $how_many_reviews, last_how_many_days => $last_how_many_days, reviews_site => $reviews_site);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_user_name_and_review_site: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **string**| User Name or Email address | 
 **how_many_reviews** | **string**| How many reviews | 
 **last_how_many_days** | **string**| How many days back | 
 **reviews_site** | **string**| Review site name | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_reviews_by_user_name_rating_and_review_site**
> ARRAY[Review] get_reviews_by_user_name_rating_and_review_site(username => $username, how_many_reviews => $how_many_reviews, minimum_ratings => $minimum_ratings, reviews_site => $reviews_site)

Get X last reviews that equal or over X stars of a review site of an account

Get X last reviews that equal or over X stars of a review site (For example, Google reviews…)

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $username = 'username_example'; # string | User Name or Email address
my $how_many_reviews = 'how_many_reviews_example'; # string | How many reviews
my $minimum_ratings = 'minimum_ratings_example'; # string | Minimum review rating (reviews that are equal or over minimumRatings stars)
my $reviews_site = 'reviews_site_example'; # string | Review site name

eval { 
    my $result = $api_instance->get_reviews_by_user_name_rating_and_review_site(username => $username, how_many_reviews => $how_many_reviews, minimum_ratings => $minimum_ratings, reviews_site => $reviews_site);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ReviewsApi->get_reviews_by_user_name_rating_and_review_site: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **string**| User Name or Email address | 
 **how_many_reviews** | **string**| How many reviews | 
 **minimum_ratings** | **string**| Minimum review rating (reviews that are equal or over minimumRatings stars) | 
 **reviews_site** | **string**| Review site name | 

### Return type

[**ARRAY[Review]**](Review.md)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **post_comment_on_review**
> post_comment_on_review(reviewid => $reviewid, commenttext => $commenttext)

Comment on a Feedback / Review

This API call posts a Comment on a Feedback / Review. When posted, the Platform sends an Email to the Commenter / Reviewer with a copy of the posted Comment. NOTE: The Moderation Team receives a copy of the Email sent to the Commenter / Reviewer  The API call has the same effect as using the Reputation Control Center (URL: https://reputationcrm.com/reputation-control), locating in the datatable the Feedback / Review that will be commented, and clicking on the 'Comment on the Platform' button to leave a Comment  Please refer https://reputationcrm.com/api/repcrm-api-img/CommentOnReview.jpg for more information 

### Example 
```perl
use Data::Dumper;
use WWW::SwaggerClient::Configuration;
use WWW::SwaggerClient::ReviewsApi;

# Configure API key authorization: api_key
$WWW::SwaggerClient::Configuration::api_key->{'key'} = 'YOUR_API_KEY';
# uncomment below to setup prefix (e.g. Bearer) for API key, if needed
#$WWW::SwaggerClient::Configuration::api_key_prefix->{'key'} = "Bearer";

my $api_instance = WWW::SwaggerClient::ReviewsApi->new();
my $reviewid = 'reviewid_example'; # string | Review ID
my $commenttext = 'commenttext_example'; # string | Comment Text 

eval { 
    $api_instance->post_comment_on_review(reviewid => $reviewid, commenttext => $commenttext);
};
if ($@) {
    warn "Exception when calling ReviewsApi->post_comment_on_review: $@\n";
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **reviewid** | **string**| Review ID | 
 **commenttext** | **string**| Comment Text  | 

### Return type

void (empty response body)

### Authorization

[api_key](../README.md#api_key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

